==> dlio_profiler_py-0.0.6-cp39-cp39-manylinux_2_34_x86_64.whl: dlio_profiler/etc/modulefiles/dlio_profiler-2.0.1.lua <==
-- LMod module file for DLIO_PROFILER

-- CMAKE_INSTALL_PREFIX: /home/runner/work/dlio-profiler/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler
-- CMAKE_BUILD_TYPE: Release
-- C Compiler: /usr/bin/cc
-- C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations
-- C FLAGS_DEBUG: -g
-- C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- C FLAGS_RELEASE: -O3 -DNDEBUG
-- CXX Compiler: /usr/bin/c++
-- CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations
-- CXX FLAGS_DEBUG: -g
-- CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- CXX FLAGS_RELEASE: -O3 -DNDEBUG
-- DLIO_PROFILER_GNU_LINUX: TRUE
-- DLIO_PROFILER_HAS_DOXYGEN: 
-- DLIO_PROFILER_HAS_STD_FILESYSTEM: TRUE
-- DLIO_PROFILER_HAS_STD_FSTREAM_FD: TRUE

help(
[[
DYnamic and Asynchronous Data streamliner (DLIO_PROFILER) version .
]])

whatis("Package: DLIO_PROFILER")
whatis("Version: ")
whatis("Description: DYnamic and Asynchronous Data streamliner (DLIO_PROFILER).")
whatis("URL: https://github.com/flux-framework/dlio_profiler")
whatis("CMAKE_INSTALL_PREFIX: /home/runner/work/dlio-profiler/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler")
whatis("CMAKE_BUILD_TYPE: Release")
whatis("C Compiler: /usr/bin/cc")
whatis("C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations")
whatis("C FLAGS_DEBUG: -g")
whatis("C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("C FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("CXX Compiler: /usr/bin/c++")
whatis("CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations")
whatis("CXX FLAGS_DEBUG: -g")
whatis("CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("CXX FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("DLIO_PROFILER_GNU_LINUX: TRUE")
whatis("DLIO_PROFILER_HAS_DOXYGEN: ")
whatis("DLIO_PROFILER_HAS_STD_FILESYSTEM: TRUE")
whatis("DLIO_PROFILER_HAS_STD_FSTREAM_FD: TRUE")

prepend_path("PATH","/home/runner/work/dlio-profiler/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler/bin")
prepend_path("LD_LIBRARY_PATH","/home/runner/work/dlio-profiler/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler/lib")

pushenv("DLIO_PROFILER_DIR","/home/runner/work/dlio-profiler/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler/")

==> dlio_profiler_py-0.0.7-cp39-cp39-manylinux_2_24_x86_64.whl: dlio_profiler/etc/modulefiles/dlio_profiler-2.0.1.lua <==
-- LMod module file for DLIO_PROFILER

-- CMAKE_INSTALL_PREFIX: /usr/WS2/haridev/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler
-- CMAKE_BUILD_TYPE: Release
-- C Compiler: /usr/lib64/ccache/cc
-- C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations
-- C FLAGS_DEBUG: -g
-- C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- C FLAGS_RELEASE: -O3 -DNDEBUG
-- CXX Compiler: /usr/lib64/ccache/c++
-- CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations
-- CXX FLAGS_DEBUG: -g
-- CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG
-- CXX FLAGS_RELEASE: -O3 -DNDEBUG
-- DLIO_PROFILER_GNU_LINUX: TRUE
-- DLIO_PROFILER_HAS_DOXYGEN: 
-- DLIO_PROFILER_HAS_STD_FILESYSTEM: TRUE
-- DLIO_PROFILER_HAS_STD_FSTREAM_FD: TRUE

help(
[[
DYnamic and Asynchronous Data streamliner (DLIO_PROFILER) version .
]])

whatis("Package: DLIO_PROFILER")
whatis("Version: ")
whatis("Description: DYnamic and Asynchronous Data streamliner (DLIO_PROFILER).")
whatis("URL: https://github.com/flux-framework/dlio_profiler")
whatis("CMAKE_INSTALL_PREFIX: /usr/WS2/haridev/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler")
whatis("CMAKE_BUILD_TYPE: Release")
whatis("C Compiler: /usr/lib64/ccache/cc")
whatis("C FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wno-deprecated-declarations")
whatis("C FLAGS_DEBUG: -g")
whatis("C FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("C FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("CXX Compiler: /usr/lib64/ccache/c++")
whatis("CXX FLAGS:  -fPIC -Wall -Wextra -pedantic -Wno-unused-parameter -Wnon-virtual-dtor -Wno-deprecated-declarations")
whatis("CXX FLAGS_DEBUG: -g")
whatis("CXX FLAGS_RELWITHDEBINFO: -O2 -g -DNDEBUG")
whatis("CXX FLAGS_RELEASE: -O3 -DNDEBUG")
whatis("DLIO_PROFILER_GNU_LINUX: TRUE")
whatis("DLIO_PROFILER_HAS_DOXYGEN: ")
whatis("DLIO_PROFILER_HAS_STD_FILESYSTEM: TRUE")
whatis("DLIO_PROFILER_HAS_STD_FSTREAM_FD: TRUE")

prepend_path("PATH","/usr/WS2/haridev/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler/bin")
prepend_path("LD_LIBRARY_PATH","/usr/WS2/haridev/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler/lib64")

pushenv("DLIO_PROFILER_DIR","/usr/WS2/haridev/dlio-profiler/build/lib.linux-x86_64-3.9/dlio_profiler/")
